==> mingw-w64-onefetch-2.15.1-1.src.tar.zst: onefetch-2.15.1/docs/README.ja.md <==
<h3 align="center"><img src="../assets/onefetch.svg" height="130px"></h3>

<h5 align="center">‎Rustで書かれたコマンドラインインターフェースのGit情報ツール‎</h5>

<p align="center">
	<a href="https://crates.io/crates/onefetch"><img src="https://img.shields.io/crates/v/onefetch.svg" alt="cargo"></a>
	<a href="https://github.com/o2sh/onefetch/actions"><img src="https://github.com/o2sh/onefetch/workflows/CI/badge.svg" alt="Build Status"></a>
  <a href="https://onefetch.dev"><img src="../assets/language-badge.svg"></a>
	<a href="https://github.com/o2sh/onefetch/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22"><img src="https://img.shields.io/github/issues/o2sh/onefetch/help%20wanted?color=green" alt="help wanted"></a>
	<a href="./LICENSE.md"><img src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
	<img src="../assets/msrv-badge.svg">
</p>

<img src="../assets/screenshot-1.png" align="right" height="240px">

Onefetch は`Rust`で書かれたコマンドラインインターフェースの Git 情報ツールで、ローカルにある Git リポジトリのプロジェクト情報やコードの統計をターミナルへ直接表示します。このツールは常にオフラインで動作し、ネットワークへのアクセスは必要ありません。

‎ デフォルトの設定ではリポジトリ内の情報は主要な言語のロゴと一緒に表示されますが、代わりに画像（ターミナルでサポートされている場合）やテキスト、または何も表示しないように設定できます。

テキストからオープンソースライセンスを自動的に検出し、ソースコードの配布ページや保留中の変更、依存関係の数（パッケージマネージャーによる）、トップコントリビューター（コミット数による）、ディスク上のサイズ、作成日、LOC（コードの行数）などの有益な情報をユーザーに提供します。

<img src="../assets/screenshot-2.png" align="right" height="240px">

Onefetch はコマンドラインフラグを使用して ASCII/テキストフォーマットのカスタマイズや情報行の無効化、ファイルやディレクトリの除外、複数のフォーマット（JSON、YAML）での出力など設定できます。

‎ 現在、Onefetch は 50 種類以上のプログラミング言語をサポートしています。選択した言語がサポートされていない場合は Issue を追加してください。

貢献は大歓迎です。詳しくは [CONTRIBUTING](../CONTRIBUTING.md) をご覧ください。

### 詳細: \[[Wiki](https://github.com/o2sh/onefetch/wiki)\] \[[Installation](https://github.com/o2sh/onefetch/wiki/Installation)\] \[[Getting Started](https://github.com/o2sh/onefetch/wiki/getting-started)\]

==> mingw-w64-onefetch-2.18.1-2.src.tar.zst: onefetch-2.18.1/docs/README.ja.md <==
<h3 align="center"><img src="../assets/onefetch.svg" height="130px"></h3>

<h5 align="center">‎Rustで書かれたコマンドラインインターフェースのGit情報ツール‎</h5>

<p align="center">
	<a href="https://crates.io/crates/onefetch"><img src="https://img.shields.io/crates/v/onefetch.svg" alt="cargo"></a>
	<a href="https://github.com/o2sh/onefetch/actions"><img src="https://github.com/o2sh/onefetch/workflows/CI/badge.svg" alt="Build Status"></a>
  <a href="https://onefetch.dev"><img src="../assets/language-badge.svg"></a>
	<a href="https://github.com/o2sh/onefetch/issues?q=is%3Aissue+is%3Aopen+label%3A%22%E2%9D%93+help+wanted%22"><img src="https://img.shields.io/github/issues/o2sh/onefetch/%E2%9D%93%20help%20wanted?color=green" alt="help wanted"></a>
	<a href="./LICENSE.md"><img src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
	<img src="../assets/msrv-badge.svg">
</p>

<img src="../assets/screenshot-1.png" align="right" height="250px">

Onefetch は`Rust`で書かれたコマンドラインインターフェースの Git 情報ツールで、ローカルにある Git リポジトリのプロジェクト情報やコードの統計をターミナルへ直接表示します。このツールは常にオフラインで動作し、ネットワークへのアクセスは必要ありません。

‎ デフォルトの設定ではリポジトリ内の情報は主要な言語のロゴと一緒に表示されますが、代わりに画像（ターミナルでサポートされている場合）やテキスト、または何も表示しないように設定できます。

テキストからオープンソースライセンスを自動的に検出し、ソースコードの配布ページや保留中の変更、依存関係の数（パッケージマネージャーによる）、トップコントリビューター（コミット数による）、ディスク上のサイズ、作成日、LOC（コードの行数）などの有益な情報をユーザーに提供します。

<img src="../assets/screenshot-2.png" align="right" height="250px">

Onefetch はコマンドラインフラグを使用して ASCII/テキストフォーマットのカスタマイズや情報行の無効化、ファイルやディレクトリの除外、複数のフォーマット（JSON、YAML）での出力など設定できます。

‎ 現在、Onefetch は 100 種類以上のプログラミング言語をサポートしています。選択した言語がサポートされていない場合は Issue を追加してください。

貢献は大歓迎です。詳しくは [CONTRIBUTING](../CONTRIBUTING.md) をご覧ください。

### 詳細: \[[Wiki](https://github.com/o2sh/onefetch/wiki)\] \[[Installation](https://github.com/o2sh/onefetch/wiki/Installation)\] \[[Getting Started](https://github.com/o2sh/onefetch/wiki/getting-started)\]
